mgkit package
=============

Subpackages
-----------

.. toctree::

   mgkit.counts
   mgkit.db
   mgkit.filter
   mgkit.io
   mgkit.mappings
   mgkit.net
   mgkit.plots
   mgkit.snps
   mgkit.utils
   mgkit.workflow

Submodules
----------

.. toctree::

   mgkit.align
   mgkit.consts
   mgkit.graphs
   mgkit.kegg
   mgkit.logger
   mgkit.simple_cache
   mgkit.taxon

Module contents
---------------

.. automodule:: mgkit
   :members:
   :undoc-members:
   :show-inheritance:
